@@ -12,7 +12,7 @@ use std::path::{Path, PathBuf};
 use std::process::exit;
 
 use atty::Stream;
-use log::{debug, error, Level};
+use log::{debug, Level};
 
 use model::opts::parse_opts;
 
@@ -106,14 +106,14 @@ impl TempApp {
 
         match self.state().arg_file() {
             Some(arg_file) => {
-                let str = util_file_contents_to_string(arg_file.as_path());
+                let str = util_file_contents_to_string(arg_file.as_path()).unwrap();
                 self.state().set_output_buffer(str.clone());
 
                 self.overwrite_idx_or_write_new_tempfile();
             }
             None => match self.state().temp_file_stack().last() {
                 Some(f) => {
-                    let string = util_file_contents_to_string(f.as_path());
+                    let string = util_file_contents_to_string(f.as_path()).unwrap();
 
                     self.state().set_output_buffer(string);
                 }
@@ -141,33 +141,28 @@ impl TempApp {
     }
 
     fn add_idx_in_stack(&mut self, f: String) {
-        match f.parse::<usize>() {
+        match f.parse::<i32>() {
             Ok(idx) => {
-                if idx < 1 {
-                    util_terminate_error(ERR_INVALID_INSERT);
-                }
                 let mut cur_files = self.state().temp_file_stack().clone();
                 cur_files.insert(
-                    util_transform_idx(idx),
+                    util_transform_idx(idx, cur_files.len()),
                     self.state().new_temp_file().clone(),
                 );
                 util_paths_to_file(cur_files, self.state().master_record_file());
             }
             Err(_error) => {
-                util_terminate_error(ERR_INVALID_INSERT);
+                util_terminate_error(ERR_INVALID_IDX);
             }
         }
     }
     fn idx_in_stack_tempfile(&mut self, f: String) -> Option<&PathBuf> {
-        match f.parse::<usize>() {
+        match f.parse::<i32>() {
             Ok(idx) => {
-                if idx < 1 {
-                    return None;
-                }
-                self.state().temp_file_stack().get(util_transform_idx(idx))
+                let stk = self.state().temp_file_stack();
+                stk.get(util_transform_idx(idx, stk.len()))
             }
-            Err(error) => {
-                error!("{}", error);
+            Err(_error) => {
+                util_terminate_error(ERR_INVALID_IDX);
                 None
             }
         }
@@ -177,12 +172,9 @@ impl TempApp {
         match self.state().output_temp_file().clone() {
             Some(stk_idx) => match self.idx_in_stack_tempfile(stk_idx.clone()) {
                 Some(f) => {
-                    print!("{}", util_file_contents_to_string(f.as_path()));
-                }
-                None => {
-                    error!("{} at idx: {}", ERR_INVALID_OUTFILE, stk_idx);
-                    exit(1)
+                    print!("{}", util_file_contents_to_string(f.as_path()).unwrap())
                 }
+                None => {}
             },
             None => {
                 if !self.state().silent() {
@@ -209,10 +201,7 @@ impl TempApp {
                 Some(f) => {
                     util_overwrite_file(f, &file_contents);
                 }
-                None => {
-                    error!("{} at idx: {}", ERR_INVALID_INFILE, stk_idx);
-                    exit(1)
-                }
+                None => {}
             },
             None => {
                 let insert_idx = self.state().insert_idx().clone();
@@ -299,7 +288,7 @@ impl TempApp {
         }
         for (i, p) in stk.iter().enumerate() {
             println!("{}: {}", i + 1, util_path_to_string(p));
-            let string = util_file_contents_to_string(p.as_path());
+            let string = util_file_contents_to_string(p.as_path()).unwrap();
             println!("{}", string.trim_end());
             util_horiz_rule();
         }
@@ -337,10 +326,7 @@ impl TempApp {
                 util_paths_to_file(col, self.state().master_record_file());
                 exit(0)
             }
-            None => {
-                error!("{} at idx: {}", ERR_INVALID_RM, stk_idx);
-                exit(1)
-            }
+            None => util_terminate_error(ERR_INVALID_IDX),
         }
     }
 }
